@@ -135,13 +135,13 @@ initLogger = function(
 
   env = new.env()
   env$stats = BBmisc::makeDataFrame(
-    ncol = 1L + n.stats + n.extras, nrow = init.size,
-    col.types = c("integer", stat.types, extra.types),
-    col.names = c("gen", stat.names, extra.names))
+    ncol = 2L + n.stats + n.extras, nrow = init.size,
+    col.types = c("integer", "numeric", stat.types, extra.types),
+    col.names = c("gen", "time.passed", stat.names, extra.names))
 
   env$stats = addClasses(env$stats, "ecr_statistics")
   env$cur.line = 1L
-  env$time.started = Sys.time()
+  env$time.started = proc.time()[3L]
   env$n.evals = 0L
   env$n.gens = 0L
   env$task = control$task
@@ -183,7 +183,7 @@ initLogger = function(
 #' @export
 updateLogger = function(log, population, fitness = NULL, n.evals, extras = NULL, ...) {
   # basic stuff
-  log$env$time.passed = Sys.time() - log$env$time.started
+  log$env$time.passed = proc.time()[3L] - log$env$time.started
   log$env$n.gens = log$env$n.gens + 1L
   log$env$n.evals = log$env$n.evals + n.evals
 
@@ -224,7 +224,7 @@ updateLogger = function(log, population, fitness = NULL, n.evals, extras = NULL,
 
   # grow memory
   if (n.log < log$env$cur.line) {
-    #catf("increasing log size! Doubling size: %i -> %i", n.log, 2 * n.log)
+    catf("increasing log size! Doubling size: %i -> %i", n.log, 2 * n.log)
     log$env$stats = rbind(log$env$stats,
       makeDataFrame(ncol = ncol(log$env$stats),
       nrow = n.log * 2,
@@ -272,10 +272,13 @@ updateLogger = function(log, population, fitness = NULL, n.evals, extras = NULL,
   #   return(stat.fun(fitness))
   # })
 
-  log$env$stats[log$env$cur.line, ] = c(list(gen = log$env$n.gens), cur.stats, extras)
+  log$env$stats[log$env$cur.line, ] = c(list(gen = log$env$n.gens, time.passed = as.numeric(log$env$time.passed)), cur.stats, extras)
 
   # store population if requested
   if (log$env$log.pop) {
+    fitdim = dim(fitness)
+    attributes(fitness) = NULL
+    dim(fitness) = fitdim
     log$env$pop[[log$env$cur.line]] = list(population = population, fitness = fitness)
   }
   log$env$cur.line = log$env$cur.line + 1L
@@ -316,7 +319,7 @@ getStatistics = function(log, trim = TRUE) {
   assertClass(log, "ecr_logger")
   assertFlag(trim)
   stats = log$env$stats
-  if (trim & (log$env$cur.line < nrow(stats))) {
+  if (trim & (log$env$cur.line - 1 < nrow(stats))) {
     stats = stats[seq.int(log$env$cur.line - 1L), , drop = FALSE]
   }
   return(stats)
@@ -348,12 +351,50 @@ getPopulations = function(log, trim = TRUE) {
   if (is.null(pops))
     stopf("This should not happen. Populations should be saved, but not found.")
 
-  if (trim & (log$env$cur.line < length(pops))) {
+  if (trim & (log$env$cur.line - 1 < length(pops))) {
     pops = pops[seq.int(log$env$cur.line - 1L)]
   }
   return(pops)
 }
 
+#' @title Access to logged population fitness.
+#'
+#' @description Returns the fitness values of all individuals as a data.frame
+#' with columns f1, ..., fo, where o is the number of objectives and column
+#' \dQuote{gen} for generation.
+#'
+#' @param log [\code{ecr_logger}]\cr
+#'   The log generated by \code{initLogger}.
+#' @param trim [\code{logical(1)}]\cr
+#'   Should unused lines in the logged be cut off?
+#'   Usually one wants this behaviour.
+#'   Thus the default is \code{TRUE}.
+#' @return [\code{list}] List of populations.
+#' @family logging
+getPopulationFitness = function(log, trim = TRUE) {
+  assertClass(log, "ecr_logger")
+  assertFlag(trim)
+
+  if (!log$log.pop)
+    stopf("Log did not store populations.")
+
+  pops = log$env$pop
+  if (is.null(pops))
+    stopf("This should not happen. Populations should be saved, but not found.")
+
+  if (trim & (log$env$cur.line - 1 < length(pops))) {
+    pops = pops[seq.int(log$env$cur.line - 1L)]
+  }
+
+  pops = lapply(pops, function(pop) {
+    pop$fitness = toParetoDf(pop$fitness)
+    return(pop)
+  })
+  reduceToSingleDataFrame(pops, what = "fitness", group.col.name = "gen")
+}
+
+
+
 #' @title Transform to long format.
 #'
 #' @description Transform the data.frame of logged statistics from wide to
